Tables have a simple wrapper that makes table creation easier.

Let's look at the simplest table.

```python
--8<-- "codes/table.py"
```

It's easy to understand.

In addition to this, tppt supports polars, pandas, pydantic, and dataclass to handle data analysis results.

```python
--8<-- "codes/polars.py"
```
